@@ -7,7 +7,7 @@ class get_studio:
   def __init__(self):
     pass
   
-  def updateScratchDB(self,ID):
+  def updateScratch(self,ID):
     info = requests.get(f"https://api.scratch.mit.edu/studios/{ID}",headers=headers)
     self.response_time = info.elapsed.total_seconds()
     self.status_code = info.status_code
